function [x,w,p]=GaussJac(n,a,b)
% JACOBI POLYNOMIALS: zeroes and gaussian integration coefficients. 
% Usage:  [x,w,p]=gausjacobi(n,[a],[b])
% defaults b=a if nargin=2, b=a=0 if nargin=1
%
% returns p=P_j(x_k), j,k=0:n-1
%  	  x=zeros of P_{n}
%	  w= Gauss integration weights
%
% Computes \int_{-1}^{1} (1-x)^a (1+x)^b f(x) dx ~ \sum(w.*f(x))
% Es. \int((1-x^2)^(1/2) cos(x) dx = pi*J1(1) ~ 1.382459687384169
% With n=5: 1.38245968779896 (relative error 3x10^-10)
%      n=10:  (relative error 3x10^-16)
% Limitations: a and b must be greater than -1.
% Bugs: n>100 may give inaccurate results or NaNs because of
%   gamma(n+...);
% See Golub and Welsch, Math.Comput. 23 (1969) 221-230
%%%%


if nargin==2,
  disp('Applying default parameter b=a');
  b=a;
else if nargin<2,
  disp('Applying default parameters a=b=0');
  a=0;
  b=0;
end
end

if(a<=-1 | b<=-1),
  error('wrong range of parameters a OR b');
end
  
disp('Building the companion matrix of Jacobi P_n(x)');
disp(' ');

N=0:n-1;

if(a+b==-1), % first coefficient would be singular hence ...
  Nm=N(2:n);
  K=[1 2.^(-Nm)./beta(Nm+1,Nm+a+b+1)./(2*Nm+a+b+1)];
else,
  K=2.^(-N)./beta(N+1,N+a+b+1)./(2*N+a+b+1);
end


Kp=2.^(-N-1)./beta(N+2,N+a+b+2)./(2*N+a+b+3);

if(a+b==-1), % first coefficient would be singular hence ...
  Nm=N(2:n);
  H=[beta(a+1,b+1) ...
	  2^(a+b+1)*gamma(Nm+a+1).*gamma(Nm+b+1)./...
	  ((2*Nm+a+b+1).*gamma(Nm+1).*gamma(Nm+a+b+1))];
else,
  H=2^(a+b+1)*gamma(N+a+1).*gamma(N+b+1)./((2*N+a+b+1).*gamma(N+1).*...
      gamma(N+a+b+1));
end

Hp=2^(a+b+1)*gamma(N+a+2).*gamma(N+b+2)./((2*N+a+b+3).*gamma(N+2).*...
    gamma(N+a+b+2));

D1=K./Kp.*sqrt(Hp./H);

R =(a-b)*N./(2*N+a+b);
Rp=(a-b)*(N+1)./(2*N+a+b+2);

R(1)=0;

D0=R-Rp;

D=diag(D1(1:n-1),1)+diag(D1(1:n-1),-1)+diag(D0);

disp('            ... and diagonalizing it:');
disp(' ');

[A,B]=eig(D);
[x,ind]=sort(-diag(B)');

A=A(:,ind);

disp('Build Jacobi polynomials and Gauss weights');
disp(' ');

p0=A;
w=p0(1,:).^2*H(1);
p=A/diag(p0(1,:));

%disp('Gauss quad rule: int(f(x) (1-x)^a (1+x)^b  dx) ~ sum(w.*f(x))');
